@@ -11,19 +11,14 @@
 # Modules and declarations
 ##############################################################################
 
-package Pod::ParseLink;
+package Pod::ParseLink v6.0.0;
 
-use 5.008;
-use strict;
+use 5.012;
 use warnings;
 
-use vars qw(@EXPORT @ISA $VERSION);
+use Exporter qw(import);
 
-use Exporter;
-@ISA    = qw(Exporter);
-@EXPORT = qw(parselink);
-
-$VERSION = '4.13';
+our @EXPORT = qw(parselink);
 
 ##############################################################################
 # Implementation
@@ -171,7 +166,8 @@ Russ Allbery <rra@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2001, 2008, 2009, 2014, 2018-2019 Russ Allbery <rra@cpan.org>
+Copyright 2001, 2008, 2009, 2014, 2018-2019, 2022, 2024 Russ Allbery
+<rra@cpan.org>
 
 This program is free software; you may redistribute it and/or modify it
 under the same terms as Perl itself.
