@@ -10,19 +10,15 @@
 # Modules and declarations
 ##############################################################################
 
-package Pod::Text::Termcap;
+package Pod::Text::Termcap v6.0.0;
 
-use 5.010;
-use strict;
+use 5.012;
+use parent qw(Pod::Text);
 use warnings;
 
-use Pod::Text ();
 use POSIX ();
 use Term::Cap;
 
-our @ISA = qw(Pod::Text);
-our $VERSION = '5.00';
-
 ##############################################################################
 # Overrides
 ##############################################################################
@@ -158,7 +154,7 @@ sub wrap {
     # $chars, used when we have to truncate and hard wrap.
     my $code = "(?:" . $self->format_regex() . ")";
     my $char = "(?>$code*[^\\n])";
-    my $shortchar = '^(' . $char . "{0,$width}(?>$code*)" . ')(?:\s+|\z)';
+    my $shortchar = '^(' . $char . "{0,$width}(?>$code*)" . ')(?:[ \t\n]+|\z)';
     my $longchar = '^(' . $char . "{$width})";
     while (length > $width) {
         if (s/$shortchar// || s/$longchar//) {
@@ -241,28 +237,33 @@ The current API based on L<Pod::Simple> was added in Pod::Text::Termcap 2.00.
 Pod::Text::Termcap 2.01 was included in Perl 5.9.3, the first version of Perl
 to incorporate those changes.
 
-Several problems with wrapping and line length were fixed as recently as
-Pod::Text::Termcap 4.11, included in Perl 5.29.1.
-
 Pod::Text::Termcap 4.13 stopped setting the TERMPATH environment variable
 during module load.  It also stopped falling back on VT100 escape sequences if
 Term::Cap was not able to find usable escape sequences, instead producing
 unformatted output for better results on dumb terminals.  The next version to
 be incorporated into Perl, 4.14, was included in Perl 5.31.8.
 
+Several problems with wrapping and line length were fixed as recently as
+Pod::Text::Termcap 6.0.0.
+
 This module inherits its API and most behavior from Pod::Text, so the details
 in L<Pod::Text/COMPATIBILITY> also apply.  Pod::Text and Pod::Text::Termcap
 have had the same module version since 4.00, included in Perl 5.23.7.  (They
 unfortunately diverge in confusing ways prior to that.)
 
+=head1 CAVEATS
+
+Line wrapping is done only at ASCII spaces and tabs, rather than using a
+correct Unicode-aware line wrapping algorithm.
+
 =head1 AUTHOR
 
 Russ Allbery <rra@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 1999, 2001-2002, 2004, 2006, 2008-2009, 2014-2015, 2018-2019, 2022
-Russ Allbery <rra@cpan.org>
+Copyright 1999, 2001-2002, 2004, 2006, 2008-2009, 2014-2015, 2018-2019, 2022,
+2024 Russ Allbery <rra@cpan.org>
 
 This program is free software; you may redistribute it and/or modify it
 under the same terms as Perl itself.
